import { ImageSettings, ImageCanvasTool } from "./tools/image-canvas-tool";
import { CanvasToolSettings, CanvasTool } from "./tools/base-canvas-tool";
import { LineCanvasDrawTool } from "./tools/line-canvas-draw-tool";
import { PencilCanvasDrawTool } from "./tools/pencil-canvas-draw-tool";
import { PanCanvasTool } from "./tools/pan-canvas-tool";
import { CanvasDrawToolSettings } from "./tools/base-canvas-draw-tool";
import { CanvasToolType } from "./enums/canvas-tool-type";
export interface CanvasSketchConfig {
    backgroundImage?: ImageSettings;
    backgroundImageCanvas?: HTMLCanvasElement;
    currentObjectIndex: number;
    panX: number;
    panY: number;
    scaleFactor: number;
    sketchCanvas: HTMLCanvasElement;
    objectStack: CanvasToolSettings[];
}
declare class CanvasSketch {
    backgroundImageTool: ImageCanvasTool;
    imageTool: ImageCanvasTool;
    lineDrawTool: LineCanvasDrawTool;
    panTool: PanCanvasTool;
    pencilDrawTool: PencilCanvasDrawTool;
    selectedTool: CanvasTool;
    private _config;
    private _backgroundImageContext;
    private _drawToolUiSettings;
    private _drawToolConfig;
    private _isBrowserSupported;
    private _sketchContext;
    private _toolConfig;
    constructor(canvasSketchConfig: CanvasSketchConfig);
    dispose(): void;
    getTool(toolType: CanvasToolType): CanvasTool | null;
    redrawBackgroundImageUsing(backgroundImageUrl: string): void;
    redrawCurrentState(): void;
    redrawSketch(): void;
    redrawSketchAt(objects: CanvasToolSettings[], newCurrentObjectIndex: number): void;
    setSelectedTool(toolType: CanvasToolType): void;
    setToolColor(color: string): void;
    setOnAddedToolStroke(onAddedStroke: (strokeSettings: CanvasDrawToolSettings) => void): void;
    setToolWidth(width: number): void;
    private _clearBackgroundImageCanvas;
    private _clearCanvas;
    private _clearSketchCanvas;
    private _drawObjects;
    private _onAddStroke;
    private _getStackToDraw;
    private _isInstanceOfDrawTool;
    private _initializeCanvasContexts;
    private _initializeCurrentDrawing;
    private _initializeTools;
    private _panTo;
    private _redrawBackgroundImage;
}
export { CanvasSketch };
